/* test_x509.h
 *
 * Copyright (C) 2006-2026 wolfSSL Inc.
 *
 * This file is part of wolfSSL.
 *
 * wolfSSL is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * wolfSSL is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1335, USA
 */

#ifndef WOLFCRYPT_TEST_X509_H
#define WOLFCRYPT_TEST_X509_H

int test_x509_rfc2818_verification_callback(void);
int test_x509_GetCAByAKID(void);
int test_x509_set_serialNumber(void);
int test_x509_verify_cert_hostname_check(void);
int test_x509_time_field_overread_via_tls(void);
int test_x509_CertFromX509_akid_overflow(void);

#define TEST_X509_DECLS                                                        \
    TEST_DECL_GROUP("x509", test_x509_rfc2818_verification_callback),          \
    TEST_DECL_GROUP("x509", test_x509_GetCAByAKID),                            \
    TEST_DECL_GROUP("x509", test_x509_set_serialNumber),                       \
    TEST_DECL_GROUP("x509", test_x509_verify_cert_hostname_check),             \
    TEST_DECL_GROUP("x509", test_x509_time_field_overread_via_tls),             \
    TEST_DECL_GROUP("x509", test_x509_CertFromX509_akid_overflow)

#endif /* WOLFCRYPT_TEST_X509_H */
